// Mdulo: Funes de parametrizao Darwin
// Company: OpenRobotics Ltda
// Verso: Darwin 2014-2023 v 6.0


#include <Ultrasonic.h>
#include <Servo.h>

//Define os pinos para o trigger e echo
#define pino_trigger 	33
#define pino_echo 	32
Ultrasonic ultrasonic(pino_trigger, pino_echo);

//Os servos podem ser instalados em qualquer uma das 4 digitais
Servo myservoD1;   
Servo myservoD2;  
Servo myservoD3;  
Servo myservoD4;  

#define m1 15
#define M1 15    //Outra porta sempre ativa = 2

#define m2 4
#define M2 4   //Outra porta sempre ativa = 16

// Mapeamento das portas digitais
#define D0 27
#define D1 26
#define D2 14
#define D3 25
#define d0 27
#define d1 26
#define d2 14
#define d3 25

#define LedInterno 18
#define SireneInterna 23
#define portaLDR 39


// Mapeamento das portas analgicas
#define A0 34
#define A1 35
#define a0 34
#define a1 35

// Definio de algumas varveis que so mais utilizadas
#define Pressionado 0
#define pressionado 0
#define sim 1
#define Sim 1
#define nao 0
#define Nao 0

#define Claro 1
#define Escuro 0

#define claro 1
#define escuro 0

#define Branco 1
#define Preto 0

#define branco 1
#define preto 0

#define Vertical 0
#define Horizontal 1

#define Frente  1
#define Re 2
#define Parar 0

#define frente  1
#define re 2
#define parar 0


void AtivarMotores()
{
   //Motor M1
   pinMode(4, OUTPUT);
   pinMode(16, OUTPUT);
   //Motor M2
   pinMode(15, OUTPUT);
   pinMode(17, OUTPUT);
   digitalWrite(4,0);
   digitalWrite(16,0);
   digitalWrite(15,0);
   digitalWrite(17,0);


}

/*void AtivarServos()
{
   //Motor M1
   pinMode(4, OUTPUT);
   pinMode(16, OUTPUT);
   //Motor M2
   pinMode(15, OUTPUT);
   pinMode(17, OUTPUT);
}
*/

void Motor(int portaMotor, int direcao)
{

int pino_1_motor;
int pino_2_motor;

   if(portaMotor==M1)
   {
     pino_1_motor = 4;
     pino_2_motor = 16;
   }
   else
   {
     pino_1_motor = 15;
     pino_2_motor = 17;
   }

   if(direcao==Frente)
   {
     digitalWrite(pino_1_motor, 1);
     digitalWrite(pino_2_motor, 0);
   }
   else if(direcao==Re)
   {
     digitalWrite(pino_1_motor, 0);
     digitalWrite(pino_2_motor, 1);
   }
   else
   {
     digitalWrite(pino_1_motor, 0);
     digitalWrite(pino_2_motor, 0);
   }
}

void MotorM1(int direcao)
{
   if(direcao==Frente)
   {
     digitalWrite(4, 1);
     digitalWrite(16, 0);
   }
   else if(direcao==Re)
   {
     digitalWrite(4, 0);
     digitalWrite(16, 1);
   }
   else
   {
     digitalWrite(4, 0);
     digitalWrite(16, 0);
   }
}

void MotorM2(int direcao)
{
   if(direcao==Frente)
   {
     digitalWrite(15, 1);
     digitalWrite(17, 0);
   }
   else if(direcao==Re)
   {
     digitalWrite(15, 0);
     digitalWrite(17, 1);
   }
   else
   {
     digitalWrite(15, 0);
     digitalWrite(17, 0);
   }
}


void PortaDeSaida(int x)
{
   pinMode(x,OUTPUT);  
}

int LeituraDaPorta(int pino)
{
   return analogRead(pino);
}

int LerInfra(int pino)
{
   if (analogRead(pino)>4000)
      return Preto;
   return Branco;
}

int LerDistancia()
{
  return ultrasonic.convert(ultrasonic.timing(),Ultrasonic::CM);
}

void LedNaPorta(int x)
{
   pinMode(x,OUTPUT);  
}

void MagneticoNaPorta(int x)
{
   pinMode(x,INPUT);  
}

void SireneNaPorta(int x)
{
   pinMode(x,OUTPUT);  
}

void LigarSirene(int x)
{
  digitalWrite(x, HIGH);   // turn the LED on (HIGH is the voltage level)
}

void DesligarSirene(int x)
{
  digitalWrite(x, LOW);   // turn the LED on (HIGH is the voltage level)
}

void BotaoNaPorta(int x)
{
  //pinMode(x,INPUT_PULLUP);
  pinMode(x,INPUT);    
}

void LigarLed(int x)
{
  digitalWrite(x, HIGH);   // turn the LED on (HIGH is the voltage level)
}

void DesligarLed(int x)
{
  digitalWrite(x, LOW);   // turn the LED on (HIGH is the voltage level)
}

void PortaDeEntrada(int x)
{
   pinMode(x,INPUT);  
}

void Ligar(int x)
{
  digitalWrite(x, HIGH);   // turn the LED on (HIGH is the voltage level)
}

void Desligar(int x)
{
  digitalWrite(x, LOW);   // turn the LED on (HIGH is the voltage level)
}

void EsperarSegundos(float x)
{
  delay(x*1000);
}


void ServoNaPorta(int x)
{
    if(x==D0)
      myservoD1.attach(x);
    if(x==D1)
      myservoD2.attach(x);
    if(x==D2)
      myservoD3.attach(x);
    if(x==D3)
      myservoD4.attach(x);
      
}

void MoverServo(int x, int pos)
{
   if(x==D0)
     myservoD1.write(pos);
   if(x==D1)
     myservoD2.write(pos);
   if(x==D2)
     myservoD3.write(pos);
   if(x==D3)
     myservoD4.write(pos);

}



int Receber(int porta)
{ 
   return digitalRead(porta);
}


int LerBotao(int porta)
{ 
  if (digitalRead(porta)==1)
      return Sim;
   return Nao;

}

void AtivarComunicacao()
{
   Serial.begin(115200);
}


void AtivarBluetooth()
{
  //mySerial.begin(9600);
 // mySerial.setTimeout(5);
}

int BluetoothEstaRecebendo()
{ 
  //if (mySerial.available()> 0)
  //    return Sim;
 //  return Nao;

}

void EnviarParaComputador(int x)
{
   Serial.println(x);
}

void EnviarParaComputador(String x)
{
   Serial.println(x);
}

void EnviarParaComputador(float x)
{
   Serial.println(x);
}


//Novas funcoes para o bluetooth
void EnviarParaBluetooth(int x)
{
  // mySerial.println(x);
}

void EnviarParaBluetooth(String x)
{
   //mySerial.println(x);
}

void EnviarParaBluetooth(float x)
{
   //mySerial.println(x);
}


//Retorna se est aceso ou nao
int LerLuz(int porta)
{
   //Luz que est na porta definida
    if (analogRead(porta)>10)
       return Escuro;
    else
       return Claro;
}

//Retorna se est aceso ou nao
int LerLuzInterna()
{
   //Luz que est na placa
    if (analogRead(portaLDR)>10)
       return Claro;
    else
       return Escuro;
}

int LerInclinacao(int porta)
{
    if (analogRead(porta)<500)
       return Vertical;
    else
       return Horizontal;
}

int LerSom(int porta)
{
   if(analogRead(porta)>500)
      return 1;
   else
      return 0;
}

int LerInfravermelho(int porta)
{
   if(analogRead(porta)>500)
      return 1;
   else
      return 0;
}

int LerMagnetico(int porta)
{
   if(analogRead(porta)<500)
      return Sim;
   else
      return Nao;
}

int ReceberDoComputador()
{
  // return Serial.read();
}

int ReceberNumeroPeloComputador()
{
   //return Serial.parseInt();
}

//Nova funcao
int ReceberDoBluetooth()
{
  // return mySerial.read();
}


//Nova funcao
int ReceberNumeroPeloBluetooth()
{
   //return mySerial.parseInt();
}


int SortearNumero(int min, int max)
{
   return random(min, max);

}

int LerTemperatura(int porta)
{ 
   return float(analogRead(porta))*5/(1023)/0.01;
}

